@@ -1079,6 +1079,12 @@ def main():
 
         cherrypy.tree.mount(wnl, mount_point, config = cfg)
 
+        # See if we have a custom WebNewsletter. If so, use that.
+        newsletter_cfg = cherrypy.tree.apps[mount_point].config['newsletter']
+        if newsletter_cfg.get('custom_webnewsletter', None):
+            wnl = newsletter_cfg.get('custom_webnewsletter', None)()
+            cherrypy.tree.mount(wnl, mount_point, config = cfg)
+
         # Need to call load() after mounting it so we 
         #   have the config from cherrypy.
         wnl.load(cherrypy.tree.apps[mount_point].config)
