@@ -38,9 +38,9 @@ We add a config item for a SendMessage.  Which can be used for things like conta
     >>> cfg['send_message_a'] = dict(send_message = True, 
     ...     mount_point = "contact", 
     ...     exposed = True, 
-    ...     email_template = "send_message_email_template", 
+    ...     email_body_template = "send_message_email_template", 
     ...     email_subject_template = "send_message_email_subject_template", 
-    ...     template = "send_message_template", 
+    ...     web_front_template = "send_message_template", 
     ...     fromaddr = "yourname@example.com", 
     ...     toaddr = "sendingto@example.com", 
     ...     validate_input = lambda kwargs: kwargs.get('input', 'ok input') == 'ok input')
